@@ -262,7 +262,7 @@ class TestMemoryCache(base.TestCase):
             name, imagefile.name, container=container, wait=True)
 
     @mock.patch.object(shade.OpenStackCloud, 'glance_client')
-    def test_create_image_put(self, glance_mock):
+    def test_create_image_put_v1(self, glance_mock):
         self.cloud.api_versions['image'] = '1'
         glance_mock.images.list.return_value = []
         self.assertEqual([], self.cloud.list_images())
@@ -280,6 +280,27 @@ class TestMemoryCache(base.TestCase):
         fake_image_dict = meta.obj_to_dict(fake_image)
         self.assertEqual([fake_image_dict], self.cloud.list_images())
 
+    @mock.patch.object(shade.OpenStackCloud, 'glance_client')
+    def test_create_image_put_v2(self, glance_mock):
+        self.cloud.api_versions['image'] = '2'
+        self.cloud.image_api_use_tasks = False
+
+        glance_mock.images.list.return_value = []
+        self.assertEqual([], self.cloud.list_images())
+
+        fake_image = fakes.FakeImage('42', '42 name', 'success')
+        glance_mock.images.create.return_value = fake_image
+        glance_mock.images.list.return_value = [fake_image]
+        self._call_create_image('42 name')
+        args = {'name': '42 name',
+                'owner_specified.shade.md5': mock.ANY,
+                'owner_specified.shade.sha256': mock.ANY}
+        glance_mock.images.create.assert_called_with(**args)
+        glance_mock.images.upload.assert_called_with(
+            image_data=mock.ANY, image_id=fake_image.id, image_size=1)
+        fake_image_dict = meta.obj_to_dict(fake_image)
+        self.assertEqual([fake_image_dict], self.cloud.list_images())
+
     @mock.patch.object(shade.OpenStackCloud, 'glance_client')
     @mock.patch.object(shade.OpenStackCloud, 'swift_client')
     def test_create_image_task(self, swift_mock, glance_mock):
@@ -340,3 +361,24 @@ class TestMemoryCache(base.TestCase):
         glance_mock.images.update.assert_called_with(**args)
         fake_image_dict = meta.obj_to_dict(fake_image)
         self.assertEqual([fake_image_dict], self.cloud.list_images())
+
+    @mock.patch.object(shade.OpenStackCloud, 'glance_client')
+    def test_cache_no_cloud_name(self, glance_mock):
+        class FakeImage(dict):
+            id = 1
+            status = 'active'
+            name = 'None Test Image'
+        fi = FakeImage(id=FakeImage.id, status=FakeImage.status,
+                       name=FakeImage.name)
+        glance_mock.images.list.return_value = [fi]
+        self.cloud.name = None
+        self.assertEqual([fi], [dict(x) for x in self.cloud.list_images()])
+        # Now test that the list was cached
+        fi2 = FakeImage(id=2, status=FakeImage.status, name=FakeImage.name)
+        fi2.id = 2
+        glance_mock.images.list.return_value = [fi, fi2]
+        self.assertEqual([fi], [dict(x) for x in self.cloud.list_images()])
+        # Invalidation too
+        self.cloud.list_images.invalidate(self.cloud)
+        self.assertEqual(
+            [fi, fi2], [dict(x) for x in self.cloud.list_images()])
